package org.ferris.journal.jws.account;

import javax.annotation.Resource;
import javax.annotation.security.RolesAllowed;
import javax.jws.WebMethod;
import javax.jws.WebParam;
import javax.jws.WebService;
import javax.naming.InitialContext;
import javax.naming.NamingException;
import javax.xml.ws.WebServiceContext;

import org.apache.log4j.Logger;
import org.ferris.journal.ejb.account.Account;
import org.ferris.journal.ejb.account.AccountLocal;


/*

  <web-app ...>
    <servlet>
      <servlet-name>AccountJws</servlet-name>
      <servlet-class>org.ferris.journal.jws.account.AccountJws</servlet-class>
    </servlet>
    <servlet-mapping>
      <servlet-name>AccountJws</servlet-name>
      <url-pattern>/jws/account/*</url-pattern>
    </servlet-mapping>
  </web-app>
  
  http://yourhost:8080/jbossws/services
  
  @SOAPBinding(style = SOAPBinding.Style.RPC)
  
 */
@WebService
public class AccountJws 
{
	private Logger log = Logger.getLogger(getClass());
	
	@Resource
    private WebServiceContext wsCtx;
	
	private AccountLocal local;
	
	private AccountLocal getAccountLocal() {
		if (local == null) 
		{
			String lookup
				= "java:comp/env/ejb/Account";
			try {
				local = (AccountLocal)new InitialContext().lookup(lookup);
				if (local == null) {
					throw new RuntimeException("JNDI lookup of \""+lookup+"\" returned null.");
				}
			} catch (NamingException e) {
				e.printStackTrace();
				throw new RuntimeException(e.getMessage(),e);
			}
		}
		return local;
	}
	
	
	@WebMethod
	public String test(
		@WebParam(name="returnThisString")
		String returnThisString
	)
	{
		log.info("ENTER test()");
		return returnThisString;
	}
	
	@WebMethod
	@RolesAllowed("JournalAccountLogin")
	public Account login(
		  @WebParam(name="username")
		  String username
		, @WebParam(name="encryptedPassword") 
		  String encryptedPassword
	) {
		log.info("ENTER login("+username+","+encryptedPassword+")");
		log.info("UserPrincipal name: " + ((wsCtx.getUserPrincipal() == null) ? "NULL" : wsCtx.getUserPrincipal().getName()));
		
		//@WebServiceRef(wsdlLocation="http://localhost:8080/helloservice/hello?wsdl")
		//static HelloService service;
		
		// lookup ejb
		AccountLocal ejb = getAccountLocal();

		// find username
		Account accnt
			= ejb.findUsername(username); {
				if (accnt == null) {
					return null;
				}
			}
		
		// passwords match?
		boolean match = encryptedPassword.equals(accnt.getPassword());
		if (!match) {
			return null;
		}
		
		return accnt;
	}
	
	@WebMethod
	@RolesAllowed("JournalAccountRegister")
	public Account register(
		@WebParam(name="account")
		Account account
	) {
		log.info("ENTER register("+account+")");
		log.info("UserPrincipal name: " + ((wsCtx.getUserPrincipal() == null) ? "NULL" : wsCtx.getUserPrincipal().getName()));
		
		// lookup ejb
		AccountLocal ejb = getAccountLocal();
		
		// find username
		Account accnt
			= ejb.findUsername(account.getUsername()); {
				if (accnt != null) {
					return null;
				}
			}
		
		// save
		account = ejb.insert(account);
		
		// return
		return account;		
	}
}
