package org.ferris.journal.jws.journal;

import java.util.List;

import javax.jws.WebMethod;
import javax.jws.WebParam;
import javax.jws.WebService;
import javax.naming.InitialContext;
import javax.naming.NamingException;

import org.apache.log4j.Logger;
import org.ferris.journal.ejb.account.Account;
import org.ferris.journal.ejb.journal.Journal;
import org.ferris.journal.ejb.journal.JournalLocal;


@WebService
public class JournalJws 
{
	private Logger log = Logger.getLogger(getClass());
	
	//@Resource
    //private WebServiceContext wsCtx;
	
	private JournalLocal local;
	
	private JournalLocal getJournalLocal() {
		if (local == null) 
		{			
			String lookup
				= "java:comp/env/ejb/Journal";
			
			log.info("Doing JNDI lookup on: " + lookup);
			try {
				local = (JournalLocal)new InitialContext().lookup(lookup);
				if (local == null) {
					throw new RuntimeException("JNDI lookup of \""+lookup+"\" returned null.");
				}
			} catch (NamingException e) {
				e.printStackTrace();
				throw new RuntimeException(e.getMessage(),e);
			}
		}
		return local;
	}
	
	
	@WebMethod
	public String test(
		@WebParam(name="returnThisString")
		String returnThisString
	)
	{
		log.info("ENTER: test("+returnThisString+")");
		return returnThisString;
	}
	
	
	@WebMethod
	public List<Journal> findAll(
		@WebParam(name="account")
		Account account
	)
	{
		log.info("ENTER: findAll("+account+")");
				
		// lookup ejb
		JournalLocal ejb = getJournalLocal();
		
		// find data
		List<Journal> data
			= ejb.findByAccount(account.getId().longValue(),null); 
		
		// return
		return data;	
	}
	
	
	@WebMethod
	public List<Journal> findActive(
		@WebParam(name="account")
		Account account
	)
	{
		log.info("ENTER: findAll("+account+")");
				
		// lookup ejb
		JournalLocal ejb = getJournalLocal();
		
		// find data
		List<Journal> data
			= ejb.findByAccount(account.getId().longValue(),Boolean.TRUE); 
		
		// return
		return data;	
	}
	
	
	@WebMethod
	public List<Journal> findInActive(
		@WebParam(name="account")
		Account account
	)
	{
		log.info("ENTER: findAll("+account+")");
				
		// lookup ejb
		JournalLocal ejb = getJournalLocal();
		
		// find data
		List<Journal> data
			= ejb.findByAccount(account.getId().longValue(),Boolean.FALSE); 
		
		// return
		return data;	
	}
	
	
	@WebMethod
	public Journal insert(
		@WebParam(name="journal")
		Journal journal
	)
	{
		log.info("ENTER: insert("+journal+")");
				
		// lookup ejb
		JournalLocal ejb = getJournalLocal();
		
		// save data
		journal
			= ejb.insert(journal); 
		
		// return
		return journal;	
	}
	
	
	@WebMethod
	public Journal update(
		@WebParam(name="journal")
		Journal journal
	)
	{
		log.info("ENTER: update("+journal+")");
				
		// lookup ejb
		JournalLocal ejb = getJournalLocal();
		
		// save data
		journal
			= ejb.update(journal); 
		
		// return
		return journal;	
	}

	
	@WebMethod
	public Journal findById(
		@WebParam(name="account")
		Account account
		,
		@WebParam(name="journalId")
		long journalId
	)
	{
		log.info("ENTER: findById("+account+","+journalId+")");
				
		// lookup ejb
		JournalLocal ejb = getJournalLocal();
		
		// find data
		Journal data
			= ejb.findById(account.getId(), journalId); 
		
		// return
		return data;	
	}
	
	
	@WebMethod
	public Boolean delete(
		@WebParam(name="account")
		Account account
		,
		@WebParam(name="journalId")
		long journalId
	)
	{
		log.info("ENTER: delete("+account+","+journalId+")");
				
		// lookup ejb
		JournalLocal ejb = getJournalLocal();
		
		// find data
		Boolean data
			= ejb.delete(account.getId(), journalId); 
		
		// return
		return data;	
	}
	
}
