package org.ferris.journal.jws.journalentry;

import java.util.Date;
import java.util.List;

import javax.jws.WebMethod;
import javax.jws.WebParam;
import javax.jws.WebService;
import javax.naming.InitialContext;
import javax.naming.NamingException;

import org.apache.log4j.Logger;
import org.ferris.journal.ejb.journal.JournalEntry;
import org.ferris.journal.ejb.journal.JournalEntryLocal;


@WebService
public class JournalEntryJws 
{
	private Logger log = Logger.getLogger(getClass());
	
	//@Resource
    //private WebServiceContext wsCtx;
	
	private JournalEntryLocal local;
	
	private JournalEntryLocal getJournalEntryLocal() {
		if (local == null) 
		{			
			String lookup
			= "java:comp/env/ejb/JournalEntry";
			
			log.info("Doing JNDI lookup on: " + lookup);
			try {
				local = (JournalEntryLocal)new InitialContext().lookup(lookup);
				if (local == null) {
					throw new RuntimeException("JNDI lookup of \""+lookup+"\" returned null.");
				}
			} catch (NamingException e) {
				e.printStackTrace();
				throw new RuntimeException(e.getMessage(),e);
			}
		}
		return local;
	}
	
	
	@WebMethod
	public String test(
		@WebParam(name="returnThisString")
		String returnThisString
	)
	{
		log.info("ENTER: test("+returnThisString+")");
		return returnThisString;
	}
	
	
	@WebMethod
	public List<JournalEntry> findByJournal(
		@WebParam(name="accountId")
		long accountId
		,
		@WebParam(name="journalId")
		long journalId
	)
	{
		log.info("ENTER: findByJournal("+accountId+","+journalId+")");
				
		// lookup ejb
		JournalEntryLocal ejb = getJournalEntryLocal();
		
		// find data
		List<JournalEntry> data
			= ejb.findByJournal(accountId,journalId); 
		
		// return
		return data;	
	}
	
	
	@WebMethod
	public JournalEntry insert(
		@WebParam(name="journalEntry")
		JournalEntry journalEntry
	)
	{
		log.info("ENTER: insert("+journalEntry+")");
				
		// lookup ejb
		JournalEntryLocal ejb = getJournalEntryLocal();
		
		// save data
		journalEntry
			= ejb.insert(journalEntry); 
		
		// return
		return journalEntry;	
	}
	
	
	@WebMethod
	public JournalEntry update(
		@WebParam(name="journalEntry")
		JournalEntry journalEntry
	)
	{
		log.info("ENTER: update("+journalEntry+")");
				
		// lookup ejb
		JournalEntryLocal ejb = getJournalEntryLocal();
		
		// save data
		journalEntry
			= ejb.update(journalEntry); 
		
		// return
		return journalEntry;	
	}

	
	@WebMethod
	public JournalEntry findById(
		@WebParam(name="accountId")
		long accountId
		,
		@WebParam(name="journalEntryId")
		long journalEntryId
	)
	{
		log.info("ENTER: findById("+accountId+","+journalEntryId+")");
				
		// lookup ejb
		JournalEntryLocal ejb = getJournalEntryLocal();
		
		// find data
		JournalEntry data
			= ejb.findById(accountId, journalEntryId); 
		
		// return
		return data;	
	}
	
	
	@WebMethod
	public Boolean delete(
		@WebParam(name="accountId")
		long accountId
		,
		@WebParam(name="journalEntryId")
		long journalEntryId
	)
	{
		log.info("ENTER: delete("+accountId+","+journalEntryId+")");
				
		// lookup ejb
		JournalEntryLocal ejb = getJournalEntryLocal();
		
		// find data
		Boolean data
			= ejb.delete(accountId, journalEntryId); 
		
		// return
		return data;	
	}
	
	
	@WebMethod
	public List<JournalEntry> search(
		@WebParam(name="accountId")
		long accountId
		,
		@WebParam(name="keyword")
		String keyword
		,
		@WebParam(name="journalIds")
		List<Long> journalIds
		,
		@WebParam(name="minDateInclusive")
		Date minDateInclusive
		,
		@WebParam(name="maxDateInclusive")
		Date maxDateInclusive
	)
	{
		log.info("ENTER: search("+accountId+","+keyword+","+journalIds+","+minDateInclusive+","+maxDateInclusive+")");
				
		// lookup ejb
		JournalEntryLocal ejb = getJournalEntryLocal();
		
		// find data
		List<JournalEntry> data
			= ejb.search(accountId, keyword, journalIds, minDateInclusive, maxDateInclusive);
		
		// return
		return data;	
	}
	
}
